@@ -22,23 +22,22 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
+
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
-	"knative.dev/pkg/logging"
+
 	"knative.dev/pkg/metrics"
 	_ "knative.dev/pkg/metrics/testing"
 	"knative.dev/pkg/ptr"
 	"knative.dev/pkg/system"
 	_ "knative.dev/pkg/system/testing"
-	tracingconfig "knative.dev/pkg/tracing/config"
 	"knative.dev/serving/pkg/apis/networking"
 	"knative.dev/serving/pkg/apis/serving"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
 	autoscalerconfig "knative.dev/serving/pkg/autoscaler/config"
-	"knative.dev/serving/pkg/deployment"
 	"knative.dev/serving/pkg/network"
 )
 
@@ -61,11 +60,9 @@ var (
 			Name:  "K_REVISION",
 			Value: "bar",
 		}, {
-			Name:  "K_CONFIGURATION",
-			Value: "cfg",
+			Name: "K_CONFIGURATION",
 		}, {
-			Name:  "K_SERVICE",
-			Value: "svc",
+			Name: "K_SERVICE",
 		}},
 	}
 
@@ -87,8 +84,7 @@ var (
 			Name:  "SERVING_NAMESPACE",
 			Value: "foo", // matches namespace
 		}, {
-			Name:  "SERVING_SERVICE",
-			Value: "svc", // matches service name
+			Name: "SERVING_SERVICE",
 		}, {
 			Name: "SERVING_CONFIGURATION",
 			// No OwnerReference
@@ -225,14 +221,7 @@ var (
 
 	defaultRevision = &v1.Revision{
 		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "foo",
-			Name:      "bar",
-			UID:       "1234",
-			Labels: map[string]string{
-				serving.ConfigurationLabelKey: "cfg",
-				serving.ServiceLabelKey:       "svc",
-				serving.RouteLabelKey:         "im-a-route",
-			},
+			UID: "1234",
 		},
 		Spec: v1.RevisionSpec{
 			TimeoutSeconds: ptr.Int64(45),
@@ -367,8 +356,10 @@ func makeDeployment(opts ...deploymentOption) *appsv1.Deployment {
 	return deploy
 }
 
-func revision(opts ...revisionOption) *v1.Revision {
+func revision(name, ns string, opts ...revisionOption) *v1.Revision {
 	revision := defaultRevision.DeepCopy()
+	revision.ObjectMeta.Name = name
+	revision.ObjectMeta.Namespace = ns
 	for _, option := range opts {
 		option(revision)
 	}
@@ -401,15 +392,12 @@ func TestMakePodSpec(t *testing.T) {
 	tests := []struct {
 		name string
 		rev  *v1.Revision
-		lc   *logging.Config
-		tc   *tracingconfig.Config
-		oc   *metrics.ObservabilityConfig
-		ac   *autoscalerconfig.Config
-		cc   *deployment.Config
+		oc   metrics.ObservabilityConfig
+		ac   autoscalerconfig.Config
 		want *corev1.PodSpec
 	}{{
 		name: "user-defined user port, queue proxy have PORT env",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
 				revision.Spec.GetContainer().Ports = []corev1.ContainerPort{{
@@ -420,11 +408,6 @@ func TestMakePodSpec(t *testing.T) {
 				)
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -441,7 +424,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "volumes passed through",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
 				revision.Spec.GetContainer().Ports = []corev1.ContainerPort{{
@@ -464,11 +447,6 @@ func TestMakePodSpec(t *testing.T) {
 				}}
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -496,7 +474,7 @@ func TestMakePodSpec(t *testing.T) {
 			})),
 	}, {
 		name: "concurrency=1 no owner",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
 				container(revision.Spec.GetContainer(),
@@ -504,11 +482,6 @@ func TestMakePodSpec(t *testing.T) {
 				)
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -518,7 +491,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "concurrency=1 no owner digest resolved",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
 				revision.Status = v1.RevisionStatus{
@@ -529,11 +502,6 @@ func TestMakePodSpec(t *testing.T) {
 				)
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(func(container *corev1.Container) {
@@ -545,7 +513,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "concurrency=1 with owner",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			withOwnerReference("parent-config"),
 			func(revision *v1.Revision) {
@@ -554,11 +522,6 @@ func TestMakePodSpec(t *testing.T) {
 				)
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -569,16 +532,11 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with http readiness probe",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withHTTPReadinessProbe(v1.DefaultUserPort),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -589,7 +547,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with tcp readiness probe",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withReadinessProbe(corev1.Handler{
 					TCPSocket: &corev1.TCPSocketAction{
@@ -599,11 +557,6 @@ func TestMakePodSpec(t *testing.T) {
 				}),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -614,16 +567,11 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with shell readiness probe",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withExecReadinessProbe([]string{"echo", "hello"}),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -635,7 +583,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with http liveness probe",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withTCPReadinessProbe(),
 				withLivenessProbe(corev1.Handler{
@@ -645,11 +593,6 @@ func TestMakePodSpec(t *testing.T) {
 				}),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -670,7 +613,7 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with tcp liveness probe",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withTCPReadinessProbe(),
 				withLivenessProbe(corev1.Handler{
@@ -678,11 +621,6 @@ func TestMakePodSpec(t *testing.T) {
 				}),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -698,19 +636,15 @@ func TestMakePodSpec(t *testing.T) {
 			}),
 	}, {
 		name: "with /var/log collection",
-		rev: revision(withContainerConcurrency(1),
+		rev: revision("bar", "foo", withContainerConcurrency(1),
 			func(revision *v1.Revision) {
 				container(revision.Spec.GetContainer(),
 					withTCPReadinessProbe(),
 				)
 			}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{
+		oc: metrics.ObservabilityConfig{
 			EnableVarLogCollection: true,
 		},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -726,18 +660,14 @@ func TestMakePodSpec(t *testing.T) {
 		),
 	}, {
 		name: "with graceful scaledown enabled",
-		rev: revision(func(revision *v1.Revision) {
+		rev: revision("bar", "foo", func(revision *v1.Revision) {
 			container(revision.Spec.GetContainer(),
 				withTCPReadinessProbe(),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{
+		ac: autoscalerconfig.Config{
 			EnableGracefulScaledown: true,
 		},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(),
@@ -752,10 +682,13 @@ func TestMakePodSpec(t *testing.T) {
 		),
 	}, {
 		name: "complex pod spec",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
-				revision.ObjectMeta.Labels = map[string]string{}
+				revision.ObjectMeta.Labels = map[string]string{
+					serving.ConfigurationLabelKey: "cfg",
+					serving.ServiceLabelKey:       "svc",
+				}
 				revision.Spec.GetContainer().Command = []string{"/bin/bash"}
 				revision.Spec.GetContainer().Args = []string{"-c", "echo Hello world"}
 				container(revision.Spec.GetContainer(),
@@ -776,11 +709,6 @@ func TestMakePodSpec(t *testing.T) {
 				revision.Spec.GetContainer().TerminationMessagePolicy = corev1.TerminationMessageReadFile
 			},
 		),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: podSpec(
 			[]corev1.Container{
 				userContainer(
@@ -806,12 +734,12 @@ func TestMakePodSpec(t *testing.T) {
 						}
 						container.TerminationMessagePolicy = corev1.TerminationMessageReadFile
 					},
-					withEnvVar("K_CONFIGURATION", ""),
-					withEnvVar("K_SERVICE", ""),
+					withEnvVar("K_CONFIGURATION", "cfg"),
+					withEnvVar("K_SERVICE", "svc"),
 				),
 				queueContainer(
 					withEnvVar("CONTAINER_CONCURRENCY", "1"),
-					withEnvVar("SERVING_SERVICE", ""),
+					withEnvVar("SERVING_SERVICE", "svc"),
 				),
 			}),
 	}}
@@ -821,7 +749,7 @@ func TestMakePodSpec(t *testing.T) {
 			quantityComparer := cmp.Comparer(func(x, y resource.Quantity) bool {
 				return x.Cmp(y) == 0
 			})
-			got, err := makePodSpec(test.rev, test.lc, test.tc, test.oc, test.ac, test.cc)
+			got, err := makePodSpec(test.rev, &logConfig, &traceConfig, &test.oc, &test.ac, &deploymentConfig)
 			if err != nil {
 				t.Fatalf("makePodSpec returned error: %v", err)
 			}
@@ -833,14 +761,8 @@ func TestMakePodSpec(t *testing.T) {
 }
 
 func TestMissingProbeError(t *testing.T) {
-	if _, err := MakeDeployment(defaultRevision,
-		&logging.Config{},
-		&tracingconfig.Config{},
-		&network.Config{},
-		&metrics.ObservabilityConfig{},
-		&autoscalerconfig.Config{},
-		&deployment.Config{},
-	); err == nil {
+	if _, err := MakeDeployment(revision("bar", "foo"), &logConfig, &traceConfig,
+		&network.Config{}, &obsConfig, &asConfig, &deploymentConfig); err == nil {
 		t.Error("expected error from MakeDeployment")
 	}
 }
@@ -849,16 +771,10 @@ func TestMakeDeployment(t *testing.T) {
 	tests := []struct {
 		name string
 		rev  *v1.Revision
-		lc   *logging.Config
-		tc   *tracingconfig.Config
-		nc   *network.Config
-		oc   *metrics.ObservabilityConfig
-		ac   *autoscalerconfig.Config
-		cc   *deployment.Config
 		want *appsv1.Deployment
 	}{{
 		name: "with concurrency=1",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withoutLabels,
 			withContainerConcurrency(1),
 			func(revision *v1.Revision) {
@@ -872,16 +788,10 @@ func TestMakeDeployment(t *testing.T) {
 				)
 			},
 		),
-		lc:   &logging.Config{},
-		tc:   &tracingconfig.Config{},
-		nc:   &network.Config{},
-		oc:   &metrics.ObservabilityConfig{},
-		ac:   &autoscalerconfig.Config{},
-		cc:   &deployment.Config{},
 		want: makeDeployment(),
 	}, {
 		name: "with owner",
-		rev: revision(
+		rev: revision("bar", "foo",
 			withoutLabels,
 			withOwnerReference("parent-config"),
 			func(revision *v1.Revision) {
@@ -895,16 +805,10 @@ func TestMakeDeployment(t *testing.T) {
 				)
 			},
 		),
-		lc:   &logging.Config{},
-		tc:   &tracingconfig.Config{},
-		nc:   &network.Config{},
-		oc:   &metrics.ObservabilityConfig{},
-		ac:   &autoscalerconfig.Config{},
-		cc:   &deployment.Config{},
 		want: makeDeployment(),
 	}, {
 		name: "with sidecar annotation override",
-		rev: revision(withoutLabels, func(revision *v1.Revision) {
+		rev: revision("bar", "foo", withoutLabels, func(revision *v1.Revision) {
 			revision.ObjectMeta.Annotations = map[string]string{
 				sidecarIstioInjectAnnotation: "false",
 			}
@@ -917,12 +821,6 @@ func TestMakeDeployment(t *testing.T) {
 				}),
 			)
 		}),
-		lc: &logging.Config{},
-		tc: &tracingconfig.Config{},
-		nc: &network.Config{},
-		oc: &metrics.ObservabilityConfig{},
-		ac: &autoscalerconfig.Config{},
-		cc: &deployment.Config{},
 		want: makeDeployment(func(deploy *appsv1.Deployment) {
 			deploy.ObjectMeta.Annotations[sidecarIstioInjectAnnotation] = "false"
 			deploy.Spec.Template.ObjectMeta.Annotations[sidecarIstioInjectAnnotation] = "false"
@@ -932,12 +830,14 @@ func TestMakeDeployment(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			// Tested above so that we can rely on it here for brevity.
-			podSpec, err := makePodSpec(test.rev, test.lc, test.tc, test.oc, test.ac, test.cc)
+			podSpec, err := makePodSpec(test.rev, &logConfig, &traceConfig,
+				&obsConfig, &asConfig, &deploymentConfig)
 			if err != nil {
 				t.Fatalf("makePodSpec returned error: %v", err)
 			}
 			test.want.Spec.Template.Spec = *podSpec
-			got, err := MakeDeployment(test.rev, test.lc, test.tc, test.nc, test.oc, test.ac, test.cc)
+			got, err := MakeDeployment(test.rev, &logConfig, &traceConfig,
+				&network.Config{}, &obsConfig, &asConfig, &deploymentConfig)
 			if err != nil {
 				t.Fatalf("got unexpected error: %v", err)
 			}
